WWTQtClient
===========

.. currentmodule:: pywwt.qt

.. autoclass:: WWTQtClient
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~WWTQtClient.close
      ~WWTQtClient.render
      ~WWTQtClient.wait

   .. rubric:: Methods Documentation

   .. automethod:: close
   .. automethod:: render
   .. automethod:: wait
